@@ -15,7 +15,7 @@ phenotype <- c("ethnicity","brc","t2d","log_ldl","sbp_cat")
 
 test_that("Test of first PGS and several Phenotypes using an assoc_table matrix and covariates", {
   expect_s3_class(
-    object = multiphenassoc(df = comorbidData, prs_col = prs, phenotype_col = phenotype, covar_col = c("age", "sex", "gen_array")),
+    object = multiphenassoc(df = comorbidData, prs_col = prs, phenotype_col = phenotype, covar_col = c("age", "sex", "gen_array"), verbose = FALSE),
     class = "data.frame"
   )
 })
